@@ -1174,8 +1174,8 @@ class LoadMaster(BaseKempAppliance):
         sso_object.populate_default_attributes(sso)
         return sso_object
 
-    def create_rule(self, name):
-        return Rule(self.access_info, name)
+    def create_rule(self, name, pattern):
+        return Rule(self.access_info, name, pattern)
 
     def get_rules(self):
         response = self._get("/showrule")
