@@ -2,11 +2,11 @@ import re
 import logging
 from collections import OrderedDict
 
-from .api_xml import (
+from python_kemptech_api.api_xml import (
     get_data,
     is_successful,
     get_error_msg)
-from .exceptions import (
+from python_kemptech_api.exceptions import (
     KempTechApiException,
     SubVsCannotCreateSubVs,
     RealServerMissingVirtualServiceInfo,
@@ -22,8 +22,8 @@ from .exceptions import (
     ClusterMissingLoadmasterInfo,
     CertificateMissingLoadmasterInfo,
     RangeMaskInvalid, VirtualServiceMissingLoadmasterInfo)
-from .generic import BaseKempObject
-from .utils import (
+from python_kemptech_api.generic import BaseKempObject
+from python_kemptech_api.utils import (
     validate_ip,
     validate_port,
     validate_protocol,
@@ -740,7 +740,8 @@ class Rule(BaseKempObject):
     _API_GET = "/showrule"
     _API_LIST = "/showrule"
     API_INIT_PARAMS = {
-        "name": "Name"
+        "name": "Name",
+        "pattern": "Pattern"
     }
     _API_BASE_PARAMS = {
         "name": "Name",
@@ -794,9 +795,10 @@ class Rule(BaseKempObject):
         else:
             self.type = types[value]
 
-    def __init__(self, loadmaster_info, name):
+    def __init__(self, loadmaster_info, name, pattern):
+        self.populate_default_attributes({})
         self.name = name
-
+        self.pattern = pattern
         try:
             self.endpoint = loadmaster_info["endpoint"]
         except KeyError:
@@ -820,16 +822,16 @@ class Rule(BaseKempObject):
 
         return base_parameters
 
-    def populate_default_attributes(self, dictionary):
+    def populate_default_attributes(self, parameters):
         """Populate object instance with standard defaults"""
         # Get data from inside tag
         # Tag is unknown since different rule types have
         # different tag names. The generic code using API_TAG
         # isn't usable in this case.
-        dictionary = dictionary.popitem()[1]
+        #parameters = parameters.popitem()[1]
 
         for attribute, tag in self._API_DEFAULT_ATTRIBUTES.items():
-            self.__setattr__(attribute, dictionary.get(tag, None))
+            setattr(self, attribute, parameters.get(tag, None))
 
         self.type_string = self.type
 
